<?php
/**
 * RCA IMAGE SLIDER
 *
 * @package 	RcaTheme.com
 * @subpackage 	mod_rca_imageslider
 * @author    	RcaTheme LLC https://www.rcatheme.com
 * @copyright 	Copyright (C) 2012 - 2025 RcaTheme.com, all rights reserved.
 * @license   	http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 *
 */

defined('_JEXEC') or die;

use Joomla\CMS\Helper\ModuleHelper;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Factory;

// Module Id and Class sfx
$moduleId = $module->id;
$moduleCssId = '#rca-imageslider-' . $module->id;

$get_moduleclass_sfx = htmlspecialchars($params->get('moduleclass_sfx', ''));
$moduleclass_sfx = '';
if (!empty($get_moduleclass_sfx)) {
	$moduleclass_sfx = ' ' . $get_moduleclass_sfx;
}

$pretext = $params->get('pretext');
$posttext = $params->get('posttext');
// Basic settings
$autoPlay =				$params->get('autoPlay', '');
$autoPlaySpeed =		$params->get('autoPlaySpeed', '');
$infinite =				$params->get('infinite', '');
$adaptHeight =			$params->get('adaptHeight', '');

$navigation =			$params->get('navigation', '');
$navBehavior =			$params->get('navBehavior', '');

$ihOpacity =			$params->get('ihOpacity', '');

$navBg =				$params->get('navBg', '');
$navTxt =				$params->get('navTxt', '');
$borderRadius =			$params->get('borderRadius', '');
$navHoverBg =			$params->get('navHoverBg', '');
$navHoverTxt =			$params->get('navHoverTxt', '');
$dotsBg =				$params->get('dotsBg', '');
$dotsHoverBg =			$params->get('dotsHoverBg', '');

$configClasses = ' nav-' . $navBehavior;

// Slides
$imgslider_items = $params->get('imgslider_items');

/* Load styles and scripts */
$assetsPath = Uri::base().'modules/mod_rca_imageslider/assets/';
$wa = Factory::getApplication()->getDocument()->getWebAssetManager();
$wa->registerAndUseStyle('mod_rca_imageslider', $assetsPath.'styles.css', [], [], []);
$wa->registerAndUseScript('mod_rca_imageslider_script', $assetsPath.'scripts.min.js', [], [], ['jquery']);

$customStyles =	
	$moduleCssId . ' .rca-imgs-arrow {
		background:' . $navBg . ';
		color:' . $navTxt . ';
		border-radius:' . $borderRadius . 'px;
	}'
	.$moduleCssId . ' .rca-imageslider-items:hover img {
		opacity:' . $ihOpacity . ';
	}'
	. $moduleCssId . ' .rca-imgs-arrow .rca-imgs-arrowicon {
		border-color:' . $navTxt . ';
	}'
	.$moduleCssId . ' .rca-imgs-arrow:hover {
		background:' . $navHoverBg . ';
	}'
	. $moduleCssId . ' .rca-imgs-arrow:hover .rca-imgs-arrowicon {
		border-color:' . $navHoverTxt . ';
	}'
	.$moduleCssId . ' ul.rcaimageslider-dots li button {
		background:' . $dotsBg . ';
	}'
	.$moduleCssId . ' ul.rcaimageslider-dots li button:hover,'
	.$moduleCssId . ' ul.rcaimageslider-dots li.rcaimageslider-active button {
		background:' . $dotsHoverBg . ';
	}
	';
$wa->addInlineStyle($customStyles);
$wa->addInlineScript('
	jQuery(document).ready(function($){
		$("' . $moduleCssId . ' .rca-imageslider-items").rcaimageslider({
			dots: '. ($navigation == 'arrows' ? 'false' : 'true') .',
			arrows: '. ($navigation == 'dots' ? 'false' : 'true') .',
			infinite: '. ($infinite ? 'true' : 'false') .',
			autoplay: '. ($autoPlay ? 'true' : 'false') .',
			autoplaySpeed: '. $autoPlaySpeed .',
			pauseOnHover: true,
			adaptiveHeight: '. ($adaptHeight ? 'true' : 'false') .',
			slidesToShow: 1,
			slidesToScroll: 1,
			prevArrow: \'<span class="rca-imgs-arrow rca-imgs-arrowprev"><span><i class="rca-imgs-arrowicon"></i></span></span>\',
			nextArrow: \'<span class="rca-imgs-arrow rca-imgs-arrownext"><span><i class="rca-imgs-arrowicon"></i></span></span>\',
		});
	});
', ['position' => 'after'], [], ['mod_rca_imageslider_script']);

require ModuleHelper::getLayoutPath('mod_rca_imageslider', $params->get('layout', 'default'));